# pymediawikidocker
Python controlled mediawiki docker application cluster installation

[![pypi](https://img.shields.io/pypi/pyversions/pymediawikidocker)](https://pypi.org/project/pymediawikidocker/)
[![Github Actions Build](https://github.com/WolfgangFahl/pymediawikidocker/workflows/Build/badge.svg?branch=main)](https://github.com/WolfgangFahl/pymediawikidocker/actions?query=workflow%3ABuild+branch%3Amain)
[![GitHub open issues](https://img.shields.io/github/issues/WolfgangFahl/pymediawikidocker.svg)](https://github.com/WolfgangFahl/pymediawikidocker/issues)
[![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/pymediawikidocker.svg)](https://github.com/WolfgangFahl/pymediawikidocker/issues/?q=is%3Aissue+is%3Aclosed)
[![PyPI Status](https://img.shields.io/pypi/v/pymediawikidocker.svg)](https://pypi.python.org/pypi/pymediawikidocker/)
[![License](https://img.shields.io/github/license/WolfgangFahl/pymediawikidocker.svg)](https://www.apache.org/licenses/LICENSE-2.0)

## Documentation
[Wiki](http://wiki.bitplan.com/index.php/pymediawikidocker)

### Authors
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl)
